from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.rules import delivery_category_pb2 as _delivery_category_pb2
from omni.pro.protos.v1.rules import delivery_locality_pb2 as _delivery_locality_pb2
from omni.pro.protos.v1.rules import delivery_schedule_pb2 as _delivery_schedule_pb2
from omni.pro.protos.v1.rules import delivery_warehouse_pb2 as _delivery_warehouse_pb2
from omni.pro.protos.v1.rules import location_pb2 as _location_pb2
from omni.pro.protos.v1.rules import stock_security_product_pb2 as _stock_security_product_pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as _warehouse_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class DeliveryMethod(_message.Message):
    __slots__ = [
        "id",
        "name",
        "delivery_warehouses",
        "type_picking_transfer",
        "validate_warehouse_code",
        "quantity_security",
        "code",
        "type_delivery",
        "delivery_location",
        "transfer_template",
        "category_template",
        "locality_available",
        "schedule_template",
        "stock_security_product",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_WAREHOUSES_FIELD_NUMBER: _ClassVar[int]
    TYPE_PICKING_TRANSFER_FIELD_NUMBER: _ClassVar[int]
    VALIDATE_WAREHOUSE_CODE_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_SECURITY_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    TYPE_DELIVERY_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_LOCATION_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    LOCALITY_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    SCHEDULE_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    STOCK_SECURITY_PRODUCT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    delivery_warehouses: _containers.RepeatedCompositeFieldContainer[_warehouse_pb2.Warehouse]
    type_picking_transfer: str
    validate_warehouse_code: str
    quantity_security: float
    code: str
    type_delivery: str
    delivery_location: _location_pb2.Location
    transfer_template: _delivery_warehouse_pb2.DeliveryWarehouse
    category_template: _delivery_category_pb2.DeliveryCategory
    locality_available: _delivery_locality_pb2.DeliveryLocality
    schedule_template: _delivery_schedule_pb2.DeliverySchedule
    stock_security_product: _stock_security_product_pb2.StockSecurityProduct
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        delivery_warehouses: _Optional[_Iterable[_Union[_warehouse_pb2.Warehouse, _Mapping]]] = ...,
        type_picking_transfer: _Optional[str] = ...,
        validate_warehouse_code: _Optional[str] = ...,
        quantity_security: _Optional[float] = ...,
        code: _Optional[str] = ...,
        type_delivery: _Optional[str] = ...,
        delivery_location: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        transfer_template: _Optional[_Union[_delivery_warehouse_pb2.DeliveryWarehouse, _Mapping]] = ...,
        category_template: _Optional[_Union[_delivery_category_pb2.DeliveryCategory, _Mapping]] = ...,
        locality_available: _Optional[_Union[_delivery_locality_pb2.DeliveryLocality, _Mapping]] = ...,
        schedule_template: _Optional[_Union[_delivery_schedule_pb2.DeliverySchedule, _Mapping]] = ...,
        stock_security_product: _Optional[_Union[_stock_security_product_pb2.StockSecurityProduct, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class DeliveryMethodCreateRequest(_message.Message):
    __slots__ = [
        "name",
        "type_picking_transfer",
        "validate_warehouse_code",
        "quantity_security",
        "code",
        "type_delivery",
        "delivery_location_id",
        "transfer_template_id",
        "category_template_id",
        "locality_available_id",
        "schedule_template_id",
        "stock_security_product_id",
        "delivery_warehouse_ids",
        "context",
    ]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_PICKING_TRANSFER_FIELD_NUMBER: _ClassVar[int]
    VALIDATE_WAREHOUSE_CODE_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_SECURITY_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    TYPE_DELIVERY_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALITY_AVAILABLE_ID_FIELD_NUMBER: _ClassVar[int]
    SCHEDULE_TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    STOCK_SECURITY_PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_WAREHOUSE_IDS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    type_picking_transfer: str
    validate_warehouse_code: str
    quantity_security: float
    code: str
    type_delivery: str
    delivery_location_id: int
    transfer_template_id: str
    category_template_id: str
    locality_available_id: str
    schedule_template_id: str
    stock_security_product_id: str
    delivery_warehouse_ids: _containers.RepeatedScalarFieldContainer[int]
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        type_picking_transfer: _Optional[str] = ...,
        validate_warehouse_code: _Optional[str] = ...,
        quantity_security: _Optional[float] = ...,
        code: _Optional[str] = ...,
        type_delivery: _Optional[str] = ...,
        delivery_location_id: _Optional[int] = ...,
        transfer_template_id: _Optional[str] = ...,
        category_template_id: _Optional[str] = ...,
        locality_available_id: _Optional[str] = ...,
        schedule_template_id: _Optional[str] = ...,
        stock_security_product_id: _Optional[str] = ...,
        delivery_warehouse_ids: _Optional[_Iterable[int]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryMethodCreateResponse(_message.Message):
    __slots__ = ["delivery_method", "response_standard"]
    DELIVERY_METHOD_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_method: DeliveryMethod
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_method: _Optional[_Union[DeliveryMethod, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryMethodReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryMethodReadResponse(_message.Message):
    __slots__ = ["delivery_methods", "meta_data", "response_standard"]
    DELIVERY_METHODS_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_methods: _containers.RepeatedCompositeFieldContainer[DeliveryMethod]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_methods: _Optional[_Iterable[_Union[DeliveryMethod, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryMethodUpdateRequest(_message.Message):
    __slots__ = ["delivery_method", "context"]
    DELIVERY_METHOD_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_method: DeliveryMethod
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_method: _Optional[_Union[DeliveryMethod, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryMethodUpdateResponse(_message.Message):
    __slots__ = ["delivery_method", "response_standard"]
    DELIVERY_METHOD_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_method: DeliveryMethod
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_method: _Optional[_Union[DeliveryMethod, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryMethodDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class DeliveryMethodDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class AddDeliveryWarehouseRequest(_message.Message):
    __slots__ = ["delivery_method_id", "delivery_warehouse_ids", "context"]
    DELIVERY_METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_WAREHOUSE_IDS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_method_id: str
    delivery_warehouse_ids: _containers.RepeatedScalarFieldContainer[int]
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_method_id: _Optional[str] = ...,
        delivery_warehouse_ids: _Optional[_Iterable[int]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AddDeliveryWarehouseResponse(_message.Message):
    __slots__ = ["delivery_method", "response_standard"]
    DELIVERY_METHOD_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_method: DeliveryMethod
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_method: _Optional[_Union[DeliveryMethod, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class RemoveDeliveryWarehouseRequest(_message.Message):
    __slots__ = ["delivery_method_id", "delivery_warehouse_ids", "context"]
    DELIVERY_METHOD_ID_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_WAREHOUSE_IDS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_method_id: str
    delivery_warehouse_ids: _containers.RepeatedScalarFieldContainer[int]
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_method_id: _Optional[str] = ...,
        delivery_warehouse_ids: _Optional[_Iterable[int]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class RemoveDeliveryWarehouseResponse(_message.Message):
    __slots__ = ["delivery_method", "response_standard"]
    DELIVERY_METHOD_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_method: DeliveryMethod
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_method: _Optional[_Union[DeliveryMethod, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import transition_pb2 as v1_dot_sales_dot_transition__pb2


class TransitionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TransitionCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.transition.TransitionService/TransitionCreate",
            request_serializer=v1_dot_sales_dot_transition__pb2.TransitionCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_transition__pb2.TransitionCreateResponse.FromString,
        )
        self.TransitionRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.transition.TransitionService/TransitionRead",
            request_serializer=v1_dot_sales_dot_transition__pb2.TransitionReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_transition__pb2.TransitionReadResponse.FromString,
        )
        self.TransitionUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.transition.TransitionService/TransitionUpdate",
            request_serializer=v1_dot_sales_dot_transition__pb2.TransitionUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_transition__pb2.TransitionUpdateResponse.FromString,
        )
        self.TransitionDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.transition.TransitionService/TransitionDelete",
            request_serializer=v1_dot_sales_dot_transition__pb2.TransitionDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_transition__pb2.TransitionDeleteResponse.FromString,
        )


class TransitionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def TransitionCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TransitionRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TransitionUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TransitionDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_TransitionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "TransitionCreate": grpc.unary_unary_rpc_method_handler(
            servicer.TransitionCreate,
            request_deserializer=v1_dot_sales_dot_transition__pb2.TransitionCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_transition__pb2.TransitionCreateResponse.SerializeToString,
        ),
        "TransitionRead": grpc.unary_unary_rpc_method_handler(
            servicer.TransitionRead,
            request_deserializer=v1_dot_sales_dot_transition__pb2.TransitionReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_transition__pb2.TransitionReadResponse.SerializeToString,
        ),
        "TransitionUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.TransitionUpdate,
            request_deserializer=v1_dot_sales_dot_transition__pb2.TransitionUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_transition__pb2.TransitionUpdateResponse.SerializeToString,
        ),
        "TransitionDelete": grpc.unary_unary_rpc_method_handler(
            servicer.TransitionDelete,
            request_deserializer=v1_dot_sales_dot_transition__pb2.TransitionDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_transition__pb2.TransitionDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.transition.TransitionService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class TransitionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def TransitionCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.transition.TransitionService/TransitionCreate",
            v1_dot_sales_dot_transition__pb2.TransitionCreateRequest.SerializeToString,
            v1_dot_sales_dot_transition__pb2.TransitionCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TransitionRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.transition.TransitionService/TransitionRead",
            v1_dot_sales_dot_transition__pb2.TransitionReadRequest.SerializeToString,
            v1_dot_sales_dot_transition__pb2.TransitionReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TransitionUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.transition.TransitionService/TransitionUpdate",
            v1_dot_sales_dot_transition__pb2.TransitionUpdateRequest.SerializeToString,
            v1_dot_sales_dot_transition__pb2.TransitionUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TransitionDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.transition.TransitionService/TransitionDelete",
            v1_dot_sales_dot_transition__pb2.TransitionDeleteRequest.SerializeToString,
            v1_dot_sales_dot_transition__pb2.TransitionDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import schedule_work_line_pb2 as v1_dot_rules_dot_schedule__work__line__pb2


class ScheduleWorkLineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ScheduleWorkLineCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineService/ScheduleWorkLineCreate",
            request_serializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineCreateResponse.FromString,
        )
        self.ScheduleWorkLineRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineService/ScheduleWorkLineRead",
            request_serializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineReadResponse.FromString,
        )
        self.ScheduleWorkLineUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineService/ScheduleWorkLineUpdate",
            request_serializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineUpdateResponse.FromString,
        )
        self.ScheduleWorkLineDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineService/ScheduleWorkLineDelete",
            request_serializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineDeleteResponse.FromString,
        )


class ScheduleWorkLineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ScheduleWorkLineCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleWorkLineRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleWorkLineUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleWorkLineDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ScheduleWorkLineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ScheduleWorkLineCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkLineCreate,
            request_deserializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineCreateResponse.SerializeToString,
        ),
        "ScheduleWorkLineRead": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkLineRead,
            request_deserializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineReadResponse.SerializeToString,
        ),
        "ScheduleWorkLineUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkLineUpdate,
            request_deserializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineUpdateResponse.SerializeToString,
        ),
        "ScheduleWorkLineDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkLineDelete,
            request_deserializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ScheduleWorkLineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ScheduleWorkLineCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineService/ScheduleWorkLineCreate",
            v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineCreateRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleWorkLineRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineService/ScheduleWorkLineRead",
            v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineReadRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleWorkLineUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineService/ScheduleWorkLineUpdate",
            v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineUpdateRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleWorkLineDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineService/ScheduleWorkLineDelete",
            v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineDeleteRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__line__pb2.ScheduleWorkLineDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import calendar_pb2 as v1_dot_rules_dot_calendar__pb2


class CalendarServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CalendarCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarCreate",
            request_serializer=v1_dot_rules_dot_calendar__pb2.CalendarCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarCreateResponse.FromString,
        )
        self.CalendarRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarRead",
            request_serializer=v1_dot_rules_dot_calendar__pb2.CalendarReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarReadResponse.FromString,
        )
        self.CalendarUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarUpdate",
            request_serializer=v1_dot_rules_dot_calendar__pb2.CalendarUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarUpdateResponse.FromString,
        )
        self.CalendarDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarDelete",
            request_serializer=v1_dot_rules_dot_calendar__pb2.CalendarDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarDeleteResponse.FromString,
        )


class CalendarServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CalendarCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CalendarRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CalendarUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CalendarDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CalendarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CalendarCreate": grpc.unary_unary_rpc_method_handler(
            servicer.CalendarCreate,
            request_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_calendar__pb2.CalendarCreateResponse.SerializeToString,
        ),
        "CalendarRead": grpc.unary_unary_rpc_method_handler(
            servicer.CalendarRead,
            request_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_calendar__pb2.CalendarReadResponse.SerializeToString,
        ),
        "CalendarUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.CalendarUpdate,
            request_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_calendar__pb2.CalendarUpdateResponse.SerializeToString,
        ),
        "CalendarDelete": grpc.unary_unary_rpc_method_handler(
            servicer.CalendarDelete,
            request_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_calendar__pb2.CalendarDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.calendar.CalendarService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class CalendarService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CalendarCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarCreate",
            v1_dot_rules_dot_calendar__pb2.CalendarCreateRequest.SerializeToString,
            v1_dot_rules_dot_calendar__pb2.CalendarCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CalendarRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarRead",
            v1_dot_rules_dot_calendar__pb2.CalendarReadRequest.SerializeToString,
            v1_dot_rules_dot_calendar__pb2.CalendarReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CalendarUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarUpdate",
            v1_dot_rules_dot_calendar__pb2.CalendarUpdateRequest.SerializeToString,
            v1_dot_rules_dot_calendar__pb2.CalendarUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CalendarDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarDelete",
            v1_dot_rules_dot_calendar__pb2.CalendarDeleteRequest.SerializeToString,
            v1_dot_rules_dot_calendar__pb2.CalendarDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
